@@ -1,7 +1,7 @@
 package Carmel;
 use strict;
 use 5.012000;
-use version; our $VERSION = version->declare('v0.1.23');
+use version; our $VERSION = version->declare('v0.1.24');
 
 1;
 __END__
@@ -14,11 +14,11 @@ Carmel - CPAN Artifact Repository Manager
 
 =head1 SYNOPSIS
 
-  # Run with a directory with cpanfile or cpanfile.snapshot
+  # Run with a directory with cpanfile
   carmel install
 
   # Manually pull a module if you don't have it
-  carmel install DBI@1.633 Plack@1.0000
+  carmel inject DBI@1.633 Plack@1.0000
 
   # list all the modules to be loaded
   carmel list
@@ -86,10 +86,9 @@ and your directory structure would look like:
 Carmel scans this directory and creates the mapping of which version
 of any package belongs to which build directory.
 
-Given the list of modules and requirements (using C<cpanfile> or even
-better C<cpanfile.snapshot> from L<Carton>), Carmel lists all the
-build directories and C<.pm> files you need, and then prepend the
-mappings of these files in the C<@INC> hook.
+Given the list of modules and requirements using C<cpanfile>, Carmel
+lists all the build directories and C<.pm> files you need, and then
+prepend the mappings of these files in the C<@INC> hook.
 
 For example, if you have:
 
